@@ -3,8 +3,6 @@ use std::marker::PhantomData;
 
 use crate::core::Decoder;
 use crate::core::Encoder;
-use crate::derive::Encode;
-use crate::derive::Decode;
 use crate::derive::FluvioDefault;
 
 use crate::record::RecordSet;
@@ -13,7 +11,7 @@ use crate::Offset;
 
 pub type DefaultFetchResponse = FetchResponse<RecordSet>;
 
-#[derive(Encode, Decode, FluvioDefault, Debug)]
+#[derive(Encoder, Decoder, FluvioDefault, Debug)]
 pub struct FetchResponse<R>
 where
     R: Encoder + Decoder + Default + Debug,
@@ -51,7 +49,7 @@ where
     }
 }
 
-#[derive(Encode, Decode, FluvioDefault, Debug)]
+#[derive(Encoder, Decoder, FluvioDefault, Debug)]
 pub struct FetchableTopicResponse<R>
 where
     R: Encoder + Decoder + Default + Debug,
@@ -64,7 +62,7 @@ where
     pub data: PhantomData<R>,
 }
 
-#[derive(Encode, Decode, FluvioDefault, Debug)]
+#[derive(Encoder, Decoder, FluvioDefault, Debug)]
 pub struct FetchablePartitionResponse<R>
 where
     R: Encoder + Decoder + Default + Debug,
@@ -78,10 +76,6 @@ where
     /// The current high water mark.
     pub high_watermark: i64,
 
-    /// The last stable offset (or LSO) of the partition which is inherited from Kafka semamntics
-    #[deprecated(since = "0.4.0", note = "Please use high_watermark")]
-    pub last_stable_offset: i64,
-
     /// next offset to fetch in case of filter
     /// consumer should return that back to SPU, othewise SPU will re-turn same filter records
     #[fluvio(min_version = 11, ignorable)]
@@ -110,7 +104,7 @@ impl FetchablePartitionResponse<RecordSet> {
     }
 }
 
-#[derive(Encode, Decode, FluvioDefault, Debug)]
+#[derive(Encoder, Decoder, FluvioDefault, Debug)]
 pub struct AbortedTransaction {
     pub producer_id: i64,
     pub first_offset: i64,
@@ -160,7 +154,6 @@ mod file {
     pub type FilePartitionResponse = FetchablePartitionResponse<FileRecordSet>;
 
     impl FileWrite for FilePartitionResponse {
-        #[allow(deprecated)]
         fn file_encode(
             &self,
             src: &mut BytesMut,
@@ -171,7 +164,6 @@ mod file {
             self.partition_index.encode(src, version)?;
             self.error_code.encode(src, version)?;
             self.high_watermark.encode(src, version)?;
-            self.last_stable_offset.encode(src, version)?;
             if version >= 11 {
                 self.next_filter_offset.encode(src, version)?;
             } else {
